@@ -87,6 +87,7 @@ from hypothesis.searchstrategy.collections import (
     ListStrategy,
     TupleStrategy,
     UniqueListStrategy,
+    UniqueSampledListStrategy,
 )
 from hypothesis.searchstrategy.datetime import (
     DateStrategy,
@@ -775,6 +776,26 @@ def lists(
         for i, f in enumerate(unique_by):
             if not callable(f):
                 raise InvalidArgument("unique_by[%i]=%r is not a callable" % (i, f))
+        # Note that lazy strategies automatically unwrap when passed to a defines_strategy
+        # function.
+        if isinstance(elements, SampledFromStrategy):
+            element_count = len(elements.elements)
+            if min_size > element_count:
+                raise InvalidArgument(
+                    "Cannot create a collection of min_size=%r unique elements with "
+                    "values drawn from only %d distinct elements"
+                    % (min_size, element_count)
+                )
+
+            if max_size is not None:
+                max_size = min(max_size, element_count)
+            else:
+                max_size = element_count
+
+            return UniqueSampledListStrategy(
+                elements=elements, max_size=max_size, min_size=min_size, keys=unique_by
+            )
+
         return UniqueListStrategy(
             elements=elements, max_size=max_size, min_size=min_size, keys=unique_by
         )
@@ -1318,8 +1339,8 @@ def from_type(thing):
 
     For example, ``everything_except(int)`` returns a strategy that can
     generate anything that ``from_type()`` can ever generate, except for
-    instances of :class:python:int, and excluding instances of types
-    added via :func:~hypothesis.strategies.register_type_strategy.
+    instances of :class:`python:int`, and excluding instances of types
+    added via :func:`~hypothesis.strategies.register_type_strategy`.
 
     This is useful when writing tests which check that invalid input is
     rejected in a certain way.
@@ -2133,10 +2154,6 @@ def data():
     """This isn't really a normal strategy, but instead gives you an object
     which can be used to draw data interactively from other strategies.
 
-    It can only be used within :func:`@given <hypothesis.given>`, not
-    :func:`find() <hypothesis.find>`. This is because the lifetime
-    of the object cannot outlast the test body.
-
     See :ref:`the rest of the documentation <interactive-draw>` for more
     complete information.
 
